@@ -31,19 +31,25 @@
 #ifndef _WIN32
 #  include <pwd.h>
 #else
-#  include <direct.h>
-#  include <glext.h>
+#  ifndef __MINGW32__
+#    include <direct.h>
+#    include <glext.h>
+#  endif
 #endif
 
 using namespace std;
 
 #include "TextureLoader.h"
-#include "Game.h"
 #include "Attack.h"
 #include "Communicator.h"
 #include "MetaState.h"
 #include "Random.h"
 
+#ifdef AUDIO_ENABLED
+#include "Sound.h"
+#include "Music.h"
+#endif
+
 #ifdef WANT_GTK
 #include "gtk-gui/gui_main.h"
 #endif
@@ -57,12 +63,13 @@ using namespace std;
  *
  * Issues and Watches
  *   slow if left sitting a long time before game start
- *   gtk+ frontend
  *   central server for online game setup
  *   remove dying_count_2
  *   find and use correct GL_LIGHT_MODEL_COLOR_CONTROL defines
  */
 
+int nosound = 0;
+
 int main ( int argc, char **argv )
 {
   setupLocalDataDirectory();
@@ -73,10 +80,11 @@ int main ( int argc, char **argv )
   char host_name[GC_HOST_NAME_SIZE];
   int port;
   int mode = 0;
+  int height = -1, width = -1;
   
   player_name[0] = '\0';
-  parseCommandLine(argc, argv, mode, port, host_name, player_name);
-  run_crack_attack(mode, port, host_name, player_name, -1, -1);
+  parseCommandLine(argc, argv, mode, port, host_name, player_name, height, width);
+  run_crack_attack(mode, port, host_name, player_name, height, width);
 
   return 0;
 }
@@ -86,7 +94,7 @@ inline void usage (   )
   cerr << "Usage: " GC_BINARY " --server [PORT] [--low] [--extreme] [--wait] "
    "[--name 'NAME']\n"
    "        <or>\n"
-   "       " GC_BINARY " SERVER[:PORT] [[--really] --low] [--name 'NAME']\n"
+   "       " GC_BINARY " SERVER PORT [[--really] --low] [--name 'NAME']\n"
    "        <or>\n"
    "       " GC_BINARY " --solo [[--really] --low] [-X] [--name 'NAME']\n"
    "        <or in short>\n"
@@ -134,14 +142,31 @@ void run_crack_attack (
 
   MetaState::programStart(mode, player_name, width, height);
 
+#ifdef AUDIO_ENABLED
+  if (!nosound) {
+    Sound::initialize();
+    Music::initialize();
+    Music::play_prelude();
+  }
+#endif
+
   glutMainLoop();
+
+#ifdef AUDIO_ENABLED
+  Music::stop();
+  Music::cleanup();
+  Sound::cleanup();
+#endif
 }
 
 void parseCommandLine ( int argc, char **argv, int &mode, int &port,
- char *host_name, char *player_name )
+ char *host_name, char *player_name , int &height, int &width )
 {
   for (int n = 1; argv[n]; n++) {
 
+    if (!strcmp(argv[n], "--nosound"))
+      nosound = 1;
+    else
     if (!strcmp(argv[n], "-s") || !strcmp(argv[n], "--server")) {
       if (mode & (CM_SERVER | CM_CLIENT | CM_SOLO)) usage();
 
@@ -192,17 +217,25 @@ void parseCommandLine ( int argc, char **argv, int &mode, int &port,
       mode |= CM_AI;
       mode |= CM_AI_MEDIUM;
 
+    } else if (!strcmp(argv[n], "--res")) {
+      if (argv[n + 1] && argv[n + 1][0] != '-')
+        height = width = atoi(argv[++n]);
+      else
+        height = width = -1;
+
     } else {
       if (mode & (CM_SERVER | CM_CLIENT | CM_SOLO)) usage();
 
       mode |= CM_CLIENT;
       strncpy(host_name, argv[n], GC_HOST_NAME_SIZE);
-      char *ptr = strchr(host_name, ':');
-      if (ptr) {
-        port = atoi(ptr + 1);
-        *ptr = '\0';
-      } else
-        port = 0;
+			++n;
+			if (n < argc) {
+				port = atoi(argv[n]);
+			} else {
+				port = 0;
+				cerr << "No port specified.\n";
+				usage();
+			}		
     }
   }
 
@@ -219,16 +252,19 @@ void parseCommandLine ( int argc, char **argv, int &mode, int &port,
       usage();
 }
 
+#define MKDIR(x,y) (mkdir(x, y))
+#ifdef _WIN32
+#  include <dir.h>
+#  undef MKDIR
+#  define MKDIR(x,y) (_mkdir(x))
+#endif
+
 void setupLocalDataDirectory (   )
 {
   char local_directory[256];
   TextureLoader::buildLocalDataDirectoryName(local_directory);
   if (!TextureLoader::fileExists(local_directory)
-#ifndef _WIN32
-   && mkdir(local_directory, 0777)
-#else
-   && _mkdir(local_directory)
-#endif
+   && MKDIR(local_directory, 0777)
    ) {
    cerr << "Error creating local data directory '" << local_directory
     << "'." << endl;
