@@ -40,7 +40,9 @@
 #  include <netdb.h>
 #  include <arpa/inet.h>
 #else
+#  include <stdlib.h>
 #  include <winsock2.h>
+#  define sleep(x) Sleep(x)
 #endif
 
 using namespace std;
@@ -126,8 +128,10 @@ void Communicator::initialize ( int mode, int port, char host_name[256],
     int connection_socket = socket(AF_INET, SOCK_STREAM, 0);
 
     sockaddr_in address;
+#ifndef _WIN32
     int val = 1;
     setsockopt (connection_socket, SOL_SOCKET, SO_REUSEADDR, &val, sizeof (int));
+#endif
     address.sin_family = AF_INET;
     address.sin_addr.s_addr = htonl(INADDR_ANY);
     address.sin_port = htons(port);
