@@ -1,3 +1,28 @@
+/*
+ * Communicator.h
+ * Daniel Nelson - 8/24/0
+ *
+ * Copyright (C) 2000  Daniel Nelson
+ * 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *
+ * Daniel Nelson - aluminumangel.org
+ * 174 W. 18th Ave.
+ * Columbus, OH  43210
+ */
+
 #ifndef COMMUNICATOR_H
 #define COMMUNICATOR_H
 
@@ -27,12 +52,17 @@ using namespace std;
 // test integer
 #define CO_TEST_INT                              (47)
 
+// protocol version number
+#define CO_VERSION                               "1.1.14"
+
 class BufferElement {
 public:
   uint32 time_stamp;
   uint32 height;
   uint32 width;
   uint32 flavor;
+
+  BufferElement (): time_stamp(0), height(0), width(0), flavor(0) { };
 };
 
 class CommunicationBuffer {
