@@ -28,13 +28,11 @@
 #include <GL/glut.h>
 #include <cassert>
 
-#ifndef _WIN32
-#else
-#  include <glext.h>
-#endif
+#include "glext.h"
 
 #include "Game.h"
 #include "Controller.h"
+#include "ActionRecorder.h"
 #include "MetaState.h"
 #include "Grid.h"
 
@@ -53,6 +51,7 @@ void Controller::gameStart (   )
 
 void Controller::keyboardPlay ( unsigned char key, int x, int y )
 {
+  bool keypressed = true;
   switch (key) {
   case GC_LEFT_KEY: case (GC_LEFT_KEY - 32):
     state |= CC_LEFT;
@@ -88,11 +87,16 @@ void Controller::keyboardPlay ( unsigned char key, int x, int y )
   case 27:
     Game::concession();
     break;
+  default:
+    keypressed = false;
   }
+  if(keypressed)
+    ActionRecorder::addAction(state);
 }
 
 void Controller::keyboardUpPlay ( unsigned char key, int x, int y )
 {
+  bool keypressed = true;
   switch (key) {
   case GC_LEFT_KEY: case (GC_LEFT_KEY - 32):
     state &= ~CC_LEFT;
@@ -115,7 +119,11 @@ void Controller::keyboardUpPlay ( unsigned char key, int x, int y )
   case GC_PAUSE_KEY: case (GC_PAUSE_KEY - 32):
     state &= ~CC_PAUSE;
     break;
+  default:
+    keypressed = false;
   }
+  if(keypressed)
+    ActionRecorder::addAction(state);
 }
 
 void Controller::specialPlay ( int key, int x, int y )
@@ -156,10 +164,25 @@ void Controller::specialUpPlay ( int key, int x, int y )
 
 void Controller::keyboardMeta ( unsigned char key, int x, int y )
 {
+	switch (key) {
 #ifdef DEVELOPMENT
-  if (key == '.') Displayer::screenShot();
+  case '.':
+    Displayer::screenShot(); break;
 #endif
-  MetaState::localKeyPressed(key == 27);
+  case GC_LEFT_KEY: case (GC_LEFT_KEY - 32):
+  case GC_RIGHT_KEY: case (GC_RIGHT_KEY - 32):
+  case GC_UP_KEY: case (GC_UP_KEY - 32):
+  case GC_DOWN_KEY: case (GC_DOWN_KEY - 32):
+  case GC_SWAP_KEY: case (GC_SWAP_KEY - 32): case ' ':
+  case GC_ADVANCE_KEY: case (GC_ADVANCE_KEY - 32): case '\r':
+  case GC_PAUSE_KEY: case (GC_PAUSE_KEY - 32):
+    MESSAGE("game key pressed");
+		MetaState::localKeyPressed(false);
+    break;
+	default:
+    MESSAGE("game key not-pressed");
+		MetaState::localKeyPressed(true);
+	}
 }
 
 void Controller::keyboardUpMeta ( unsigned char key, int x, int y )
