@@ -33,22 +33,18 @@
 #  include <pwd.h>
 #else
 #  include <direct.h>
-#  include <glext.h>
 #endif
 
+#include "../glext.h"
+
 #include <gtk/gtk.h>
 
 using namespace std;
 
-#include "TextureLoader.h"
-#include "Game.h"
-#include "Attack.h"
-#include "Communicator.h"
-#include "MetaState.h"
-#include "Random.h"
-#include "gtk-gui/support.h"
-#include "gtk-gui/interface.h"
-#include "gtk-gui/persist.h"
+#include "../MetaState.h"
+#include "support.h"
+#include "interface.h"
+#include "persist.h"
 
 #define GC_HOST_NAME_SIZE (256)
 int glut_argc;
@@ -69,29 +65,18 @@ char **glut_argv;
 
 int gui_main ( int argc, char **argv )
 {
-  char player_name[GC_PLAYER_NAME_LENGTH];
-  char host_name[GC_HOST_NAME_SIZE];
-  int port;
-  int mode = 0;
   GtkWidget *winCrackAttackSplash = NULL;
   
   // Backup argc and argv to initialize glut in the child process
   glut_argc = argc;
   glut_argv = argv;
 
-  player_name[0] = '\0';
-
-  gtk_set_locale ();
-  if (gtk_init_check (&argc, &argv)) {
-    add_pixmap_directory (PACKAGE_DATA_DIR "/" PACKAGE);
+    gtk_init(&argc, &argv);
+    add_pixmap_directory (GC_DATA_DIRECTORY(""));
     winCrackAttackSplash = create_winCrackAttackSplash ();
 		gui_data_read(winCrackAttackSplash);
     gtk_widget_show (winCrackAttackSplash);
     gtk_main ();
-  } else {
-    parseCommandLine(argc, argv, mode, port, host_name, player_name);
-    run_crack_attack(mode, port, host_name, player_name, -1, -1);
-  }
 
   return 0;
 }
