@@ -24,12 +24,8 @@
 
 
 void
-gui_data_save                 (GtkButton *);
+gui_data_save                 (GtkWidget *);
 
 
 void
 gui_data_read                 (GtkWidget *);
-
-
-int
-gui_get_dimensions            (GtkButton *);
