@@ -27,10 +27,7 @@
 
 #include <GL/glut.h>
 
-#ifndef _WIN32
-#else
-#  include <glext.h>
-#endif
+#include "glext.h"
 
 using namespace std;
 
@@ -157,4 +154,4 @@ void Displayer::generateGarbageThickCornerList (   )
   glDisableClientState(GL_VERTEX_ARRAY);
   glDisableClientState(GL_NORMAL_ARRAY);
   glDisableClientState(GL_TEXTURE_COORD_ARRAY);
-};
+}
